@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from collections.abc import Iterator
 from collections.abc import Sequence
 from typing import overload
 
@@ -8,7 +9,7 @@ from musictool.card import Card
 from musictool.note import SpecificNote
 from musictool.noteset import NoteSet
 
-CHROMATIC_NOTESET = NoteSet(frozenset(config.chromatic_notes))
+CHROMATIC_NOTESET = NoteSet.from_str(config.chromatic_notes)
 
 
 class NoteRange(Sequence[SpecificNote], Card):
@@ -39,17 +40,22 @@ class NoteRange(Sequence[SpecificNote], Card):
         if 0 <= item < len(self):
             q = self.noteset.add_note(self.start, item)
             return q
-        elif -len(self) <= item < 0: return self.noteset.add_note(self.stop, item + 1)
-        else: raise IndexError('index out of range')
+        elif -len(self) <= item < 0:
+            return self.noteset.add_note(self.stop, item + 1)
+        else:
+            raise IndexError('index out of range')
 
     @overload
-    def __getitem__(self, i: int) -> SpecificNote: ...
+    def __getitem__(self, i: int) -> SpecificNote:
+        ...
 
     @overload
-    def __getitem__(self, s: slice) -> NoteRange: ...
+    def __getitem__(self, s: slice) -> NoteRange:
+        ...
 
     def __getitem__(self, item: int | slice) -> SpecificNote | NoteRange:
-        if isinstance(item, int): return self._getitem_int(item)
+        if isinstance(item, int):
+            return self._getitem_int(item)
         elif isinstance(item, slice):
             # if item.start is None:
             start = 0 if item.start is None else item.start
@@ -57,18 +63,30 @@ class NoteRange(Sequence[SpecificNote], Card):
             if not 0 <= start <= stop <= len(self):
                 raise IndexError('NoteRange slice is out of range, negative indexing is not supported')
             return NoteRange(self._getitem_int(start), self._getitem_int(stop), self.noteset)
-        else: raise TypeError(f'NoteRange indices must be integers or slices, got {type(item)}')
+        else:
+            raise TypeError(f'NoteRange indices must be integers or slices, got {type(item)}')
 
     def __contains__(self, item: object) -> bool:
         if not isinstance(item, SpecificNote):
             return False
         return item.abstract in self.noteset and self.start <= item <= self.stop
 
-    def __iter__(self): return (self[i] for i in range(len(self)))
-    def __repr__(self): return f'NoteRange({self.start}, {self.stop}, noteset={self.noteset})'
-    def __len__(self): return self.noteset.subtract(self.stop, self.start) + 1
-    def __eq__(self, other): return self._key == other._key
-    def __hash__(self): return hash(self._key)
+    def __iter__(self) -> Iterator[SpecificNote]:
+        return (self[i] for i in range(len(self)))
+
+    def __repr__(self) -> str:
+        return f'NoteRange({self.start}, {self.stop}, noteset={self.noteset})'
+
+    def __len__(self) -> int:
+        return self.noteset.subtract(self.stop, self.start) + 1
+
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, NoteRange):
+            return NotImplemented
+        return self._key == other._key
+
+    def __hash__(self) -> int:
+        return hash(self._key)
 
     def to_piano_image(self) -> str:
         from musictool.piano import Piano  # hack to fix circular import
@@ -84,11 +102,13 @@ class NoteRange(Sequence[SpecificNote], Card):
         title: str | None = None,
         subtitle: str | None = None,
         header_href: str | None = None,
+        background_color: str | None = None,
     ) -> str:
         return self.repr_card(
             html_classes=html_classes,
             title=title or f'NoteRange({self.start}, {self.stop})',
             subtitle=subtitle,
             header_href=header_href,
+            background_color=background_color,
             piano_html=self.to_piano_image(),
         )
