@@ -4,6 +4,8 @@ import functools
 import itertools
 from collections import defaultdict
 
+import colortool
+
 from musictool import config
 from musictool.card import Card
 from musictool.chord import Chord
@@ -62,9 +64,9 @@ class Scale(NoteSet, Card):
 
     def __init__(
         self,
-        notes: frozenset[str | Note],
+        notes: frozenset[Note],
         *,
-        root: str | Note,
+        root: Note,
     ):
         # if not isinstance(root, str | Note):
 
@@ -105,7 +107,7 @@ class Scale(NoteSet, Card):
                 return Scale.from_name(note, name)
         raise KeyError(f'relative {relative_name} scale not found')
 
-    def to_piano_image(self):
+    def to_piano_image(self) -> str:
         return Piano(note_colors={note: config.scale_colors[scale] for note, scale in self.note_scales.items()})._repr_svg_()
 
     def _repr_html_(
@@ -114,6 +116,7 @@ class Scale(NoteSet, Card):
         title: str | None = None,
         subtitle: str | None = None,
         header_href: str | None = None,
+        background_color: str | None = None,
     ) -> str:
         html_classes += self.name,
 
@@ -125,6 +128,7 @@ class Scale(NoteSet, Card):
             title=title or f'{self.root.name} {self.name}{C_name}',
             subtitle=subtitle,
             header_href=header_href or self.root.name,
+            background_color=background_color,
             piano_html=self.to_piano_image(),
         )
 
@@ -148,10 +152,10 @@ class ComparedScales(Card):
         if right.kind == 'diatonic':
             self.shared_triads = frozenset(left.triads) & frozenset(right.triads)
 
-    def to_piano_image(self):
+    def to_piano_image(self) -> str:
         return Piano(
             note_colors={note: config.scale_colors[scale] for note, scale in self.right.note_scales.items()},
-            top_rect_colors=dict.fromkeys(self.del_notes, RED) | dict.fromkeys(self.new_notes, GREEN) | dict.fromkeys(self.shared_notes, BLUE),
+            top_rect_colors=dict.fromkeys(self.del_notes, RED) | dict.fromkeys(self.new_notes, GREEN) | dict.fromkeys(self.shared_notes, BLUE),  # type: ignore
             squares={
                 chord.root: {
                     'fill_color': config.chord_colors[chord.name],
@@ -170,22 +174,33 @@ class ComparedScales(Card):
         title: str | None = None,
         subtitle: str | None = None,
         header_href: str | None = None,
+        background_color: str | None = None,
     ) -> str:
 
-        if C_name := self.right.note_scales.get(Note('C'), ''):
-            C_name = f' | C {C_name}'
+        if left_root_name := self.right.note_scales.get(self.left.root, ''):
+            if background_color is None:
+                background_color = colortool.css_hex(config.scale_colors[left_root_name])
+            left_root_name = f' | {self.left.root.name} {left_root_name}'
 
         return self.repr_card(
             html_classes=html_classes,
-            title=title or f'{self.right.root.name} {self.right.name}{C_name}',
+            title=title or f'{self.right.root.name} {self.right.name}{left_root_name}',
             subtitle=subtitle,
             header_href=header_href or self.right.root.name,
+            background_color=background_color,
             piano_html=self.to_piano_image(),
         )
 
-    def __eq__(self, other): return self.key == other.key
-    def __hash__(self): return hash(self.key)
-    def __repr__(self): return f'ComparedScale({self.left.root} {self.left.name} | {self.right.root} {self.right.name})'
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, ComparedScales):
+            return NotImplemented
+        return self.key == other.key
+
+    def __hash__(self) -> int:
+        return hash(self.key)
+
+    def __repr__(self) -> str:
+        return f'ComparedScale({self.left.root} {self.left.name} | {self.right.root} {self.right.name})'
 
 
 diatonic = {(root, name): Scale.from_name(root, name) for root, name in itertools.product(config.chromatic_notes, config.diatonic)}
